"use strict";
var byline = require("byline");
var LogcatHelper = (function () {
    function LogcatHelper($childProcess, $logger) {
        this.$childProcess = $childProcess;
        this.$logger = $logger;
        this.lineRegex = /.\/(.+?)\s*\(\s*(\d+?)\): (.*)/;
    }
    LogcatHelper.prototype.start = function (deviceIdentifier, adbPath) {
        var _this = this;
        var adbLogcat = this.$childProcess.spawn(adbPath, ["-s", deviceIdentifier, "logcat"]);
        var lineStream = byline(adbLogcat.stdout);
        adbLogcat.stderr.on("data", function (data) {
            _this.$logger.trace("ADB logcat stderr: " + data.toString());
        });
        adbLogcat.on("close", function (code) {
            if (code !== 0) {
                _this.$logger.trace("ADB process exited with code " + code.toString());
            }
        });
        lineStream.on('data', function (line) {
            var lineText = line.toString();
            var log = _this.getConsoleLogFromLine(lineText);
            if (log) {
                if (log.tag) {
                    _this.$logger.out("%s: %s", log.tag, log.message);
                }
                else {
                    _this.$logger.out(log.message);
                }
            }
        });
        return adbLogcat;
    };
    LogcatHelper.prototype.getConsoleLogFromLine = function (lineText) {
        var acceptedTags = ["chromium", "Web Console", "JS"];
        var match = lineText.match(this.lineRegex);
        if (match) {
            if (acceptedTags.indexOf(match[1]) !== -1) {
                return { tag: match[1], message: match[3] };
            }
        }
        else if (_.any(acceptedTags, function (tag) {
            return lineText.indexOf(tag) !== -1;
        })) {
            return { message: match[3] };
        }
        return null;
    };
    return LogcatHelper;
})();
exports.LogcatHelper = LogcatHelper;
$injector.register("logcatHelper", LogcatHelper);
